@@ -52,7 +52,7 @@
 #include <libgnome/gnome-desktop-item.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-uri.h>
-#include <menu-tree.h>
+#include <gmenu-tree.h>
 
 #define sure_string(s)                    ((const char *)((s)!=NULL?(s):""))
 #define DESKTOP_ENTRY_GROUP		  "Desktop Entry"
@@ -111,6 +111,14 @@ eel_open_with_dialog_finalize (GObject *object)
 
 	dialog = EEL_OPEN_WITH_DIALOG (object);
 
+	if (dialog->details->add_icons_idle_id) {
+		g_source_remove (dialog->details->add_icons_idle_id);
+	}
+
+	if (dialog->details->add_items_idle_id) {
+		g_source_remove (dialog->details->add_items_idle_id);
+	}
+	
 	g_free (dialog->details->uri);
 	g_free (dialog->details->mime_type);
 	g_free (dialog->details->mime_description);
@@ -504,32 +512,41 @@ eel_open_with_dialog_add_icon_idle (EelOpenWithDialog *dialog)
 }
 
 static int
-compare_applications (MenuTreeEntry *a,
-		      MenuTreeEntry *b)
+compare_applications (GMenuTreeEntry *a,
+		      GMenuTreeEntry *b)
 {
-	return g_utf8_collate (menu_tree_entry_get_name (a),
-			       menu_tree_entry_get_name (b));
+	return g_utf8_collate (gmenu_tree_entry_get_name (a),
+			       gmenu_tree_entry_get_name (b));
 }
 
 static GSList *
-get_all_applications_from_dir (MenuTreeDirectory *directory,
-			       GSList            *list)
+get_all_applications_from_dir (GMenuTreeDirectory *directory,
+			       GSList             *list)
 {
-	GSList *subdirs;
+	GSList *contents;
 	GSList *l;
 
-	list = g_slist_concat (list,
-	menu_tree_directory_get_entries (directory));
+	contents = gmenu_tree_directory_get_contents (directory);
 
-	subdirs = menu_tree_directory_get_subdirs (directory);
-	for (l = subdirs; l; l = l->next) {
-		MenuTreeDirectory *subdir = l->data;
+	for (l = contents; l; l = l->next) {
+		GMenuTreeItem *item = l->data;
 
-		list = get_all_applications_from_dir (subdir, list);
+		switch (gmenu_tree_item_get_type (item)) {
+			case GMENU_TREE_ITEM_DIRECTORY:
+				list = get_all_applications_from_dir (GMENU_TREE_DIRECTORY (item), list);
+				gmenu_tree_item_unref (item);
+				break;
 
-		menu_tree_directory_unref (subdir);
+			case GMENU_TREE_ITEM_ENTRY:
+				list = g_slist_prepend (list, item);
+				break;
+
+			default:
+				break;
+		}
 	}
-	g_slist_free (subdirs);
+
+	g_slist_free (contents);
 
 	return list;
 }
@@ -538,18 +555,18 @@ get_all_applications_from_dir (MenuTreeDirectory *directory,
 static GSList *
 get_all_applications (void)
 {
-	MenuTree          *tree;
-	MenuTreeDirectory *root;
-	GSList            *retval;
+	GMenuTree          *tree;
+	GMenuTreeDirectory *root;
+	GSList             *retval;
 
-	tree = menu_tree_lookup ("applications.menu");
+	tree = gmenu_tree_lookup ("applications.menu", GMENU_TREE_FLAGS_NONE);
 
-	root = menu_tree_get_root_directory (tree);
+	root = gmenu_tree_get_root_directory (tree);
 
 	retval = get_all_applications_from_dir (root, NULL);
 
-	menu_tree_directory_unref (root);
-	menu_tree_unref (tree);
+	gmenu_tree_item_unref (root);
+	gmenu_tree_unref (tree);
 
 	retval = g_slist_sort (retval,
 			       (GCompareFunc) compare_applications);
@@ -580,22 +597,22 @@ eel_open_with_dialog_add_items_idle (EelOpenWithDialog *dialog)
 	
 	prev_name = NULL;
 	for (l = all_applications; l; l = l->next) {
-		MenuTreeEntry *entry = l->data;
-		GtkTreeIter    iter;
-		GtkTreePath   *path;
+		GMenuTreeEntry *entry = l->data;
+		GtkTreeIter     iter;
+		GtkTreePath    *path;
 
-		if (prev_name && strcmp (menu_tree_entry_get_name (entry), prev_name) == 0) {
-			menu_tree_entry_unref (entry);
+		if (prev_name && strcmp (gmenu_tree_entry_get_name (entry), prev_name) == 0) {
+			gmenu_tree_item_unref (entry);
 			continue;
 		}
 
 		gtk_list_store_append (dialog->details->program_list_store, &iter);
 		gtk_list_store_set (dialog->details->program_list_store, &iter,
 				    COLUMN_ICON,      NULL,
-				    COLUMN_ICON_FILE, menu_tree_entry_get_icon (entry),
-				    COLUMN_NAME,      menu_tree_entry_get_name (entry),
-				    COLUMN_COMMENT,   menu_tree_entry_get_comment (entry),
-				    COLUMN_PATH,      menu_tree_entry_get_desktop_file_path (entry),
+				    COLUMN_ICON_FILE, gmenu_tree_entry_get_icon (entry),
+				    COLUMN_NAME,      gmenu_tree_entry_get_name (entry),
+				    COLUMN_COMMENT,   gmenu_tree_entry_get_comment (entry),
+				    COLUMN_PATH,      gmenu_tree_entry_get_desktop_file_path (entry),
 				    -1);
 
 		path = gtk_tree_model_get_path (GTK_TREE_MODEL (dialog->details->program_list_store), &iter);
@@ -603,8 +620,8 @@ eel_open_with_dialog_add_items_idle (EelOpenWithDialog *dialog)
 			dialog->details->add_icon_paths = g_slist_prepend (dialog->details->add_icon_paths, path);
 		}
 
-		prev_name = menu_tree_entry_get_name (entry);
-		menu_tree_entry_unref (entry);
+		prev_name = gmenu_tree_entry_get_name (entry);
+		gmenu_tree_item_unref (entry);
 	}
 	g_slist_free (all_applications);
 
