@@ -1,7 +1,6 @@
 #ifndef TEST_H
 #define TEST_H
 
-#include <eel/eel-text-caption.h>
 #include <gtk/gtkwindow.h>
 
 void       test_init                            (int                    *argc,
@@ -33,19 +32,8 @@ void       test_pixbuf_draw_rectangle_tiled     (GdkPixbuf              *pixbuf,
 						 int                     opacity);
 void       test_window_set_title_with_pid       (GtkWindow              *window,
 						 const char             *title);
-int        test_text_caption_get_text_as_int    (const EelTextCaption   *text_caption);
 char *     eel_pixmap_file                      (const char             *partial_path);
 
-// /* Preferences hacks */
-// void test_text_caption_set_text_for_int_preferences            (EelTextCaption       *text_caption,
-// 								const char                *name);
-// void test_text_caption_set_text_for_string_preferences         (EelTextCaption       *text_caption,
-// 								const char                *name);
-// void test_text_caption_set_text_for_default_int_preferences    (EelTextCaption       *text_caption,
-// 								const char                *name);
-// void test_text_caption_set_text_for_default_string_preferences (EelTextCaption       *text_caption,
-// 								const char                *name);
-
 #include <eel/eel-debug.h>
 #include <eel/eel.h>
 #include <gtk/gtk.h>
